"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SqsEnvelope = void 0;
const sqs_js_1 = require("../schemas/sqs.js");
const envelope_js_1 = require("./envelope.js");
const errors_js_1 = require("../errors.js");
/**
 *  SQS Envelope to extract array of Records
 *
 *  The record's body parameter is a string, though it can also be a JSON encoded string.
 *  Regardless of its type it'll be parsed into a BaseModel object.
 *
 *  Note: Records will be parsed the same way so if model is str,
 *  all items in the list will be parsed as str and npt as JSON (and vice versa)
 */
class SqsEnvelope extends envelope_js_1.Envelope {
    static parse(data, schema) {
        const parsedEnvelope = sqs_js_1.SqsSchema.parse(data);
        return parsedEnvelope.Records.map((record) => {
            return super.parse(record.body, schema);
        });
    }
    static safeParse(data, schema) {
        const parsedEnvelope = sqs_js_1.SqsSchema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse Sqs Envelope', parsedEnvelope.error),
                originalEvent: data,
            };
        }
        const parsedRecords = [];
        for (const record of parsedEnvelope.data.Records) {
            const parsedRecord = super.safeParse(record.body, schema);
            if (!parsedRecord.success) {
                return {
                    success: false,
                    error: new errors_js_1.ParseError('Failed to parse Sqs Record', parsedRecord.error),
                    originalEvent: data,
                };
            }
            parsedRecords.push(parsedRecord.data);
        }
        return { success: true, data: parsedRecords };
    }
}
exports.SqsEnvelope = SqsEnvelope;
