import { z } from 'zod';
declare const APIGatewayCert: z.ZodObject<{
    clientCertPem: z.ZodString;
    subjectDN: z.ZodString;
    issuerDN: z.ZodString;
    serialNumber: z.ZodString;
    validity: z.ZodObject<{
        notBefore: z.ZodString;
        notAfter: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        notBefore: string;
        notAfter: string;
    }, {
        notBefore: string;
        notAfter: string;
    }>;
}, "strip", z.ZodTypeAny, {
    clientCertPem: string;
    subjectDN: string;
    issuerDN: string;
    serialNumber: string;
    validity: {
        notBefore: string;
        notAfter: string;
    };
}, {
    clientCertPem: string;
    subjectDN: string;
    issuerDN: string;
    serialNumber: string;
    validity: {
        notBefore: string;
        notAfter: string;
    };
}>;
declare const APIGatewayProxyEventSchema: z.ZodObject<{
    version: z.ZodOptional<z.ZodString>;
    authorizationToken: z.ZodOptional<z.ZodString>;
    identitySource: z.ZodOptional<z.ZodString>;
    methodArn: z.ZodOptional<z.ZodString>;
    type: z.ZodOptional<z.ZodEnum<["TOKEN", "REQUEST"]>>;
    resource: z.ZodString;
    path: z.ZodString;
    httpMethod: z.ZodEnum<["GET", "POST", "PUT", "PATCH", "DELETE", "HEAD", "OPTIONS"]>;
    headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    queryStringParameters: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    multiValueHeaders: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodArray<z.ZodString, "many">>>;
    multiValueQueryStringParameters: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodArray<z.ZodString, "many">>>;
    requestContext: z.ZodEffects<z.ZodObject<{
        accountId: z.ZodString;
        apiId: z.ZodString;
        authorizer: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            claims: z.ZodOptional<z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodAny>>>;
            scopes: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strip", z.ZodTypeAny, {
            claims?: Record<string, any> | null | undefined;
            scopes?: string[] | null | undefined;
        }, {
            claims?: Record<string, any> | null | undefined;
            scopes?: string[] | null | undefined;
        }>>>;
        stage: z.ZodString;
        protocol: z.ZodString;
        identity: z.ZodObject<{
            accessKey: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            accountId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            apiKey: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            apiKeyId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            caller: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            cognitoAuthenticationProvider: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            cognitoAuthenticationType: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            cognitoIdentityId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            cognitoIdentityPoolId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            principalOrgId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            sourceIp: z.ZodOptional<z.ZodString>;
            user: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            userAgent: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            userArn: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            clientCert: z.ZodOptional<z.ZodNullable<z.ZodObject<{
                clientCertPem: z.ZodString;
                subjectDN: z.ZodString;
                issuerDN: z.ZodString;
                serialNumber: z.ZodString;
                validity: z.ZodObject<{
                    notBefore: z.ZodString;
                    notAfter: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    notBefore: string;
                    notAfter: string;
                }, {
                    notBefore: string;
                    notAfter: string;
                }>;
            }, "strip", z.ZodTypeAny, {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            }, {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            }>>>;
        }, "strip", z.ZodTypeAny, {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        }, {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        }>;
        requestId: z.ZodString;
        requestTime: z.ZodString;
        requestTimeEpoch: z.ZodNumber;
        resourceId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        resourcePath: z.ZodString;
        domainName: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        domainPrefix: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        extendedRequestId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        httpMethod: z.ZodEnum<["GET", "POST", "PUT", "PATCH", "DELETE", "HEAD", "OPTIONS"]>;
        path: z.ZodString;
        connectedAt: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
        connectionId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        eventType: z.ZodOptional<z.ZodNullable<z.ZodEnum<["CONNECT", "MESSAGE", "DISCONNECT"]>>>;
        messageDirection: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        messageId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        routeKey: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        operationName: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        path: string;
        accountId: string;
        apiId: string;
        stage: string;
        protocol: string;
        identity: {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        };
        requestId: string;
        requestTime: string;
        requestTimeEpoch: number;
        resourcePath: string;
        httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        authorizer?: {
            claims?: Record<string, any> | null | undefined;
            scopes?: string[] | null | undefined;
        } | null | undefined;
        resourceId?: string | null | undefined;
        domainName?: string | null | undefined;
        domainPrefix?: string | null | undefined;
        extendedRequestId?: string | null | undefined;
        connectedAt?: number | null | undefined;
        connectionId?: string | null | undefined;
        eventType?: "CONNECT" | "MESSAGE" | "DISCONNECT" | null | undefined;
        messageDirection?: string | null | undefined;
        messageId?: string | null | undefined;
        routeKey?: string | null | undefined;
        operationName?: string | null | undefined;
    }, {
        path: string;
        accountId: string;
        apiId: string;
        stage: string;
        protocol: string;
        identity: {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        };
        requestId: string;
        requestTime: string;
        requestTimeEpoch: number;
        resourcePath: string;
        httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        authorizer?: {
            claims?: Record<string, any> | null | undefined;
            scopes?: string[] | null | undefined;
        } | null | undefined;
        resourceId?: string | null | undefined;
        domainName?: string | null | undefined;
        domainPrefix?: string | null | undefined;
        extendedRequestId?: string | null | undefined;
        connectedAt?: number | null | undefined;
        connectionId?: string | null | undefined;
        eventType?: "CONNECT" | "MESSAGE" | "DISCONNECT" | null | undefined;
        messageDirection?: string | null | undefined;
        messageId?: string | null | undefined;
        routeKey?: string | null | undefined;
        operationName?: string | null | undefined;
    }>, {
        path: string;
        accountId: string;
        apiId: string;
        stage: string;
        protocol: string;
        identity: {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        };
        requestId: string;
        requestTime: string;
        requestTimeEpoch: number;
        resourcePath: string;
        httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        authorizer?: {
            claims?: Record<string, any> | null | undefined;
            scopes?: string[] | null | undefined;
        } | null | undefined;
        resourceId?: string | null | undefined;
        domainName?: string | null | undefined;
        domainPrefix?: string | null | undefined;
        extendedRequestId?: string | null | undefined;
        connectedAt?: number | null | undefined;
        connectionId?: string | null | undefined;
        eventType?: "CONNECT" | "MESSAGE" | "DISCONNECT" | null | undefined;
        messageDirection?: string | null | undefined;
        messageId?: string | null | undefined;
        routeKey?: string | null | undefined;
        operationName?: string | null | undefined;
    }, {
        path: string;
        accountId: string;
        apiId: string;
        stage: string;
        protocol: string;
        identity: {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        };
        requestId: string;
        requestTime: string;
        requestTimeEpoch: number;
        resourcePath: string;
        httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        authorizer?: {
            claims?: Record<string, any> | null | undefined;
            scopes?: string[] | null | undefined;
        } | null | undefined;
        resourceId?: string | null | undefined;
        domainName?: string | null | undefined;
        domainPrefix?: string | null | undefined;
        extendedRequestId?: string | null | undefined;
        connectedAt?: number | null | undefined;
        connectionId?: string | null | undefined;
        eventType?: "CONNECT" | "MESSAGE" | "DISCONNECT" | null | undefined;
        messageDirection?: string | null | undefined;
        messageId?: string | null | undefined;
        routeKey?: string | null | undefined;
        operationName?: string | null | undefined;
    }>;
    pathParameters: z.ZodOptional<z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>>>;
    stageVariables: z.ZodOptional<z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>>>;
    isBase64Encoded: z.ZodOptional<z.ZodBoolean>;
    body: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    path: string;
    httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
    resource: string;
    requestContext: {
        path: string;
        accountId: string;
        apiId: string;
        stage: string;
        protocol: string;
        identity: {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        };
        requestId: string;
        requestTime: string;
        requestTimeEpoch: number;
        resourcePath: string;
        httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        authorizer?: {
            claims?: Record<string, any> | null | undefined;
            scopes?: string[] | null | undefined;
        } | null | undefined;
        resourceId?: string | null | undefined;
        domainName?: string | null | undefined;
        domainPrefix?: string | null | undefined;
        extendedRequestId?: string | null | undefined;
        connectedAt?: number | null | undefined;
        connectionId?: string | null | undefined;
        eventType?: "CONNECT" | "MESSAGE" | "DISCONNECT" | null | undefined;
        messageDirection?: string | null | undefined;
        messageId?: string | null | undefined;
        routeKey?: string | null | undefined;
        operationName?: string | null | undefined;
    };
    version?: string | undefined;
    authorizationToken?: string | undefined;
    identitySource?: string | undefined;
    methodArn?: string | undefined;
    type?: "TOKEN" | "REQUEST" | undefined;
    headers?: Record<string, string> | undefined;
    queryStringParameters?: Record<string, string> | undefined;
    multiValueHeaders?: Record<string, string[]> | undefined;
    multiValueQueryStringParameters?: Record<string, string[]> | undefined;
    pathParameters?: Record<string, string> | null | undefined;
    stageVariables?: Record<string, string> | null | undefined;
    isBase64Encoded?: boolean | undefined;
    body?: string | undefined;
}, {
    path: string;
    httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
    resource: string;
    requestContext: {
        path: string;
        accountId: string;
        apiId: string;
        stage: string;
        protocol: string;
        identity: {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        };
        requestId: string;
        requestTime: string;
        requestTimeEpoch: number;
        resourcePath: string;
        httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        authorizer?: {
            claims?: Record<string, any> | null | undefined;
            scopes?: string[] | null | undefined;
        } | null | undefined;
        resourceId?: string | null | undefined;
        domainName?: string | null | undefined;
        domainPrefix?: string | null | undefined;
        extendedRequestId?: string | null | undefined;
        connectedAt?: number | null | undefined;
        connectionId?: string | null | undefined;
        eventType?: "CONNECT" | "MESSAGE" | "DISCONNECT" | null | undefined;
        messageDirection?: string | null | undefined;
        messageId?: string | null | undefined;
        routeKey?: string | null | undefined;
        operationName?: string | null | undefined;
    };
    version?: string | undefined;
    authorizationToken?: string | undefined;
    identitySource?: string | undefined;
    methodArn?: string | undefined;
    type?: "TOKEN" | "REQUEST" | undefined;
    headers?: Record<string, string> | undefined;
    queryStringParameters?: Record<string, string> | undefined;
    multiValueHeaders?: Record<string, string[]> | undefined;
    multiValueQueryStringParameters?: Record<string, string[]> | undefined;
    pathParameters?: Record<string, string> | null | undefined;
    stageVariables?: Record<string, string> | null | undefined;
    isBase64Encoded?: boolean | undefined;
    body?: string | undefined;
}>;
export { APIGatewayProxyEventSchema, APIGatewayCert };
//# sourceMappingURL=apigw.d.ts.map