"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SqsMsgAttributeSchema = exports.SqsAttributesSchema = exports.SqsRecordSchema = exports.SqsSchema = void 0;
const zod_1 = require("zod");
const SqsMsgAttributeSchema = zod_1.z.object({
    stringValue: zod_1.z.string().optional(),
    binaryValue: zod_1.z.string().optional(),
    stringListValues: zod_1.z.array(zod_1.z.string()).optional(),
    binaryListValues: zod_1.z.array(zod_1.z.string()).optional(),
    dataType: zod_1.z.string(),
});
exports.SqsMsgAttributeSchema = SqsMsgAttributeSchema;
const SqsAttributesSchema = zod_1.z.object({
    ApproximateReceiveCount: zod_1.z.string(),
    ApproximateFirstReceiveTimestamp: zod_1.z.string(),
    MessageDeduplicationId: zod_1.z.string().optional(),
    MessageGroupId: zod_1.z.string().optional(),
    SenderId: zod_1.z.string(),
    SentTimestamp: zod_1.z.string(),
    SequenceNumber: zod_1.z.string().optional(),
    AWSTraceHeader: zod_1.z.string().optional(),
    /**
     * Undocumented, but used by AWS to support their re-drive functionality in the console
     */
    DeadLetterQueueSourceArn: zod_1.z.string().optional(),
});
exports.SqsAttributesSchema = SqsAttributesSchema;
const SqsRecordSchema = zod_1.z.object({
    messageId: zod_1.z.string(),
    receiptHandle: zod_1.z.string(),
    body: zod_1.z.string(),
    attributes: SqsAttributesSchema,
    messageAttributes: zod_1.z.record(zod_1.z.string(), SqsMsgAttributeSchema),
    md5OfBody: zod_1.z.string(),
    md5OfMessageAttributes: zod_1.z.string().optional().nullable(),
    eventSource: zod_1.z.literal('aws:sqs'),
    eventSourceARN: zod_1.z.string(),
    awsRegion: zod_1.z.string(),
});
exports.SqsRecordSchema = SqsRecordSchema;
const SqsSchema = zod_1.z.object({
    Records: zod_1.z.array(SqsRecordSchema),
});
exports.SqsSchema = SqsSchema;
