import { Envelope } from './envelope.js';
import { VpcLatticeV2Schema } from '../schemas/index.js';
import { ParseError } from '../errors.js';
/**
 * Amazon VPC Lattice envelope to extract data within body key
 */
export class VpcLatticeV2Envelope extends Envelope {
    static parse(data, schema) {
        const parsedEnvelope = VpcLatticeV2Schema.parse(data);
        return super.parse(parsedEnvelope.body, schema);
    }
    static safeParse(data, schema) {
        const parsedEnvelope = VpcLatticeV2Schema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new ParseError('Failed to parse VpcLatticeV2 envelope.', parsedEnvelope.error),
                originalEvent: data,
            };
        }
        const parsedBody = super.safeParse(parsedEnvelope.data.body, schema);
        if (!parsedBody.success) {
            return {
                success: false,
                error: new ParseError('Failed to parse VpcLatticeV2 body.', parsedBody.error),
                originalEvent: data,
            };
        }
        return parsedBody;
    }
}
