import { z } from 'zod';
declare const DynamoDBStreamChangeRecord: z.ZodObject<{
    ApproximateCreationDateTime: z.ZodOptional<z.ZodNumber>;
    Keys: z.ZodRecord<z.ZodString, z.ZodRecord<z.ZodString, z.ZodAny>>;
    NewImage: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
    OldImage: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
    SequenceNumber: z.ZodString;
    SizeBytes: z.ZodNumber;
    StreamViewType: z.ZodEnum<["NEW_IMAGE", "OLD_IMAGE", "NEW_AND_OLD_IMAGES", "KEYS_ONLY"]>;
}, "strip", z.ZodTypeAny, {
    Keys: Record<string, Record<string, any>>;
    SequenceNumber: string;
    SizeBytes: number;
    StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
    ApproximateCreationDateTime?: number | undefined;
    NewImage?: Record<string, any> | undefined;
    OldImage?: Record<string, any> | undefined;
}, {
    Keys: Record<string, Record<string, any>>;
    SequenceNumber: string;
    SizeBytes: number;
    StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
    ApproximateCreationDateTime?: number | undefined;
    NewImage?: Record<string, any> | undefined;
    OldImage?: Record<string, any> | undefined;
}>;
declare const UserIdentity: z.ZodObject<{
    type: z.ZodEnum<["Service"]>;
    principalId: z.ZodLiteral<"dynamodb.amazonaws.com">;
}, "strip", z.ZodTypeAny, {
    type: "Service";
    principalId: "dynamodb.amazonaws.com";
}, {
    type: "Service";
    principalId: "dynamodb.amazonaws.com";
}>;
declare const DynamoDBStreamRecord: z.ZodObject<{
    eventID: z.ZodString;
    eventName: z.ZodEnum<["INSERT", "MODIFY", "REMOVE"]>;
    eventVersion: z.ZodString;
    eventSource: z.ZodLiteral<"aws:dynamodb">;
    awsRegion: z.ZodString;
    eventSourceARN: z.ZodString;
    dynamodb: z.ZodObject<{
        ApproximateCreationDateTime: z.ZodOptional<z.ZodNumber>;
        Keys: z.ZodRecord<z.ZodString, z.ZodRecord<z.ZodString, z.ZodAny>>;
        NewImage: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
        OldImage: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
        SequenceNumber: z.ZodString;
        SizeBytes: z.ZodNumber;
        StreamViewType: z.ZodEnum<["NEW_IMAGE", "OLD_IMAGE", "NEW_AND_OLD_IMAGES", "KEYS_ONLY"]>;
    }, "strip", z.ZodTypeAny, {
        Keys: Record<string, Record<string, any>>;
        SequenceNumber: string;
        SizeBytes: number;
        StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
        ApproximateCreationDateTime?: number | undefined;
        NewImage?: Record<string, any> | undefined;
        OldImage?: Record<string, any> | undefined;
    }, {
        Keys: Record<string, Record<string, any>>;
        SequenceNumber: string;
        SizeBytes: number;
        StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
        ApproximateCreationDateTime?: number | undefined;
        NewImage?: Record<string, any> | undefined;
        OldImage?: Record<string, any> | undefined;
    }>;
    userIdentity: z.ZodOptional<z.ZodObject<{
        type: z.ZodEnum<["Service"]>;
        principalId: z.ZodLiteral<"dynamodb.amazonaws.com">;
    }, "strip", z.ZodTypeAny, {
        type: "Service";
        principalId: "dynamodb.amazonaws.com";
    }, {
        type: "Service";
        principalId: "dynamodb.amazonaws.com";
    }>>;
}, "strip", z.ZodTypeAny, {
    eventID: string;
    eventName: "INSERT" | "MODIFY" | "REMOVE";
    eventVersion: string;
    eventSource: "aws:dynamodb";
    awsRegion: string;
    eventSourceARN: string;
    dynamodb: {
        Keys: Record<string, Record<string, any>>;
        SequenceNumber: string;
        SizeBytes: number;
        StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
        ApproximateCreationDateTime?: number | undefined;
        NewImage?: Record<string, any> | undefined;
        OldImage?: Record<string, any> | undefined;
    };
    userIdentity?: {
        type: "Service";
        principalId: "dynamodb.amazonaws.com";
    } | undefined;
}, {
    eventID: string;
    eventName: "INSERT" | "MODIFY" | "REMOVE";
    eventVersion: string;
    eventSource: "aws:dynamodb";
    awsRegion: string;
    eventSourceARN: string;
    dynamodb: {
        Keys: Record<string, Record<string, any>>;
        SequenceNumber: string;
        SizeBytes: number;
        StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
        ApproximateCreationDateTime?: number | undefined;
        NewImage?: Record<string, any> | undefined;
        OldImage?: Record<string, any> | undefined;
    };
    userIdentity?: {
        type: "Service";
        principalId: "dynamodb.amazonaws.com";
    } | undefined;
}>;
declare const DynamoDBStreamSchema: z.ZodObject<{
    Records: z.ZodArray<z.ZodObject<{
        eventID: z.ZodString;
        eventName: z.ZodEnum<["INSERT", "MODIFY", "REMOVE"]>;
        eventVersion: z.ZodString;
        eventSource: z.ZodLiteral<"aws:dynamodb">;
        awsRegion: z.ZodString;
        eventSourceARN: z.ZodString;
        dynamodb: z.ZodObject<{
            ApproximateCreationDateTime: z.ZodOptional<z.ZodNumber>;
            Keys: z.ZodRecord<z.ZodString, z.ZodRecord<z.ZodString, z.ZodAny>>;
            NewImage: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
            OldImage: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
            SequenceNumber: z.ZodString;
            SizeBytes: z.ZodNumber;
            StreamViewType: z.ZodEnum<["NEW_IMAGE", "OLD_IMAGE", "NEW_AND_OLD_IMAGES", "KEYS_ONLY"]>;
        }, "strip", z.ZodTypeAny, {
            Keys: Record<string, Record<string, any>>;
            SequenceNumber: string;
            SizeBytes: number;
            StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
            ApproximateCreationDateTime?: number | undefined;
            NewImage?: Record<string, any> | undefined;
            OldImage?: Record<string, any> | undefined;
        }, {
            Keys: Record<string, Record<string, any>>;
            SequenceNumber: string;
            SizeBytes: number;
            StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
            ApproximateCreationDateTime?: number | undefined;
            NewImage?: Record<string, any> | undefined;
            OldImage?: Record<string, any> | undefined;
        }>;
        userIdentity: z.ZodOptional<z.ZodObject<{
            type: z.ZodEnum<["Service"]>;
            principalId: z.ZodLiteral<"dynamodb.amazonaws.com">;
        }, "strip", z.ZodTypeAny, {
            type: "Service";
            principalId: "dynamodb.amazonaws.com";
        }, {
            type: "Service";
            principalId: "dynamodb.amazonaws.com";
        }>>;
    }, "strip", z.ZodTypeAny, {
        eventID: string;
        eventName: "INSERT" | "MODIFY" | "REMOVE";
        eventVersion: string;
        eventSource: "aws:dynamodb";
        awsRegion: string;
        eventSourceARN: string;
        dynamodb: {
            Keys: Record<string, Record<string, any>>;
            SequenceNumber: string;
            SizeBytes: number;
            StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
            ApproximateCreationDateTime?: number | undefined;
            NewImage?: Record<string, any> | undefined;
            OldImage?: Record<string, any> | undefined;
        };
        userIdentity?: {
            type: "Service";
            principalId: "dynamodb.amazonaws.com";
        } | undefined;
    }, {
        eventID: string;
        eventName: "INSERT" | "MODIFY" | "REMOVE";
        eventVersion: string;
        eventSource: "aws:dynamodb";
        awsRegion: string;
        eventSourceARN: string;
        dynamodb: {
            Keys: Record<string, Record<string, any>>;
            SequenceNumber: string;
            SizeBytes: number;
            StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
            ApproximateCreationDateTime?: number | undefined;
            NewImage?: Record<string, any> | undefined;
            OldImage?: Record<string, any> | undefined;
        };
        userIdentity?: {
            type: "Service";
            principalId: "dynamodb.amazonaws.com";
        } | undefined;
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    Records: {
        eventID: string;
        eventName: "INSERT" | "MODIFY" | "REMOVE";
        eventVersion: string;
        eventSource: "aws:dynamodb";
        awsRegion: string;
        eventSourceARN: string;
        dynamodb: {
            Keys: Record<string, Record<string, any>>;
            SequenceNumber: string;
            SizeBytes: number;
            StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
            ApproximateCreationDateTime?: number | undefined;
            NewImage?: Record<string, any> | undefined;
            OldImage?: Record<string, any> | undefined;
        };
        userIdentity?: {
            type: "Service";
            principalId: "dynamodb.amazonaws.com";
        } | undefined;
    }[];
}, {
    Records: {
        eventID: string;
        eventName: "INSERT" | "MODIFY" | "REMOVE";
        eventVersion: string;
        eventSource: "aws:dynamodb";
        awsRegion: string;
        eventSourceARN: string;
        dynamodb: {
            Keys: Record<string, Record<string, any>>;
            SequenceNumber: string;
            SizeBytes: number;
            StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
            ApproximateCreationDateTime?: number | undefined;
            NewImage?: Record<string, any> | undefined;
            OldImage?: Record<string, any> | undefined;
        };
        userIdentity?: {
            type: "Service";
            principalId: "dynamodb.amazonaws.com";
        } | undefined;
    }[];
}>;
export { DynamoDBStreamSchema, DynamoDBStreamRecord, DynamoDBStreamChangeRecord, UserIdentity, };
//# sourceMappingURL=dynamodb.d.ts.map