import { z } from 'zod';
declare const KinesisFirehoseSchema: z.ZodObject<{
    region: z.ZodString;
    invocationId: z.ZodString;
    deliveryStreamArn: z.ZodString;
    sourceKinesisStreamArn: z.ZodOptional<z.ZodString>;
    records: z.ZodArray<z.ZodObject<{
        approximateArrivalTimestamp: z.ZodNumber;
        recordId: z.ZodString;
        kinesisRecordMetaData: z.ZodOptional<z.ZodObject<{
            shardId: z.ZodString;
            partitionKey: z.ZodString;
            approximateArrivalTimestamp: z.ZodNumber;
            sequenceNumber: z.ZodString;
            subsequenceNumber: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
            shardId: string;
            subsequenceNumber: number;
        }, {
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
            shardId: string;
            subsequenceNumber: number;
        }>>;
        data: z.ZodEffects<z.ZodString, string, string>;
    }, "strip", z.ZodTypeAny, {
        data: string;
        approximateArrivalTimestamp: number;
        recordId: string;
        kinesisRecordMetaData?: {
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
            shardId: string;
            subsequenceNumber: number;
        } | undefined;
    }, {
        data: string;
        approximateArrivalTimestamp: number;
        recordId: string;
        kinesisRecordMetaData?: {
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
            shardId: string;
            subsequenceNumber: number;
        } | undefined;
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    region: string;
    records: {
        data: string;
        approximateArrivalTimestamp: number;
        recordId: string;
        kinesisRecordMetaData?: {
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
            shardId: string;
            subsequenceNumber: number;
        } | undefined;
    }[];
    invocationId: string;
    deliveryStreamArn: string;
    sourceKinesisStreamArn?: string | undefined;
}, {
    region: string;
    records: {
        data: string;
        approximateArrivalTimestamp: number;
        recordId: string;
        kinesisRecordMetaData?: {
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
            shardId: string;
            subsequenceNumber: number;
        } | undefined;
    }[];
    invocationId: string;
    deliveryStreamArn: string;
    sourceKinesisStreamArn?: string | undefined;
}>;
declare const KinesisFirehoseSqsSchema: z.ZodObject<{
    region: z.ZodString;
    invocationId: z.ZodString;
    deliveryStreamArn: z.ZodString;
    sourceKinesisStreamArn: z.ZodOptional<z.ZodString>;
    records: z.ZodArray<z.ZodObject<{
        approximateArrivalTimestamp: z.ZodNumber;
        recordId: z.ZodString;
        kinesisRecordMetaData: z.ZodOptional<z.ZodObject<{
            shardId: z.ZodString;
            partitionKey: z.ZodString;
            approximateArrivalTimestamp: z.ZodNumber;
            sequenceNumber: z.ZodString;
            subsequenceNumber: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
            shardId: string;
            subsequenceNumber: number;
        }, {
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
            shardId: string;
            subsequenceNumber: number;
        }>>;
        data: z.ZodEffects<z.ZodString, string | {
            messageId: string;
            body: string;
            eventSource: "aws:sqs";
            awsRegion: string;
            eventSourceARN: string;
            receiptHandle: string;
            attributes: {
                ApproximateReceiveCount: string;
                ApproximateFirstReceiveTimestamp: string;
                SenderId: string;
                SentTimestamp: string;
                MessageDeduplicationId?: string | undefined;
                MessageGroupId?: string | undefined;
                SequenceNumber?: string | undefined;
                AWSTraceHeader?: string | undefined;
                DeadLetterQueueSourceArn?: string | undefined;
            };
            messageAttributes: Record<string, {
                dataType: string;
                stringValue?: string | undefined;
                binaryValue?: string | undefined;
                stringListValues?: string[] | undefined;
                binaryListValues?: string[] | undefined;
            }>;
            md5OfBody: string;
            md5OfMessageAttributes?: string | null | undefined;
        }, string>;
    }, "strip", z.ZodTypeAny, {
        data: (string | {
            messageId: string;
            body: string;
            eventSource: "aws:sqs";
            awsRegion: string;
            eventSourceARN: string;
            receiptHandle: string;
            attributes: {
                ApproximateReceiveCount: string;
                ApproximateFirstReceiveTimestamp: string;
                SenderId: string;
                SentTimestamp: string;
                MessageDeduplicationId?: string | undefined;
                MessageGroupId?: string | undefined;
                SequenceNumber?: string | undefined;
                AWSTraceHeader?: string | undefined;
                DeadLetterQueueSourceArn?: string | undefined;
            };
            messageAttributes: Record<string, {
                dataType: string;
                stringValue?: string | undefined;
                binaryValue?: string | undefined;
                stringListValues?: string[] | undefined;
                binaryListValues?: string[] | undefined;
            }>;
            md5OfBody: string;
            md5OfMessageAttributes?: string | null | undefined;
        }) & (string | {
            messageId: string;
            body: string;
            eventSource: "aws:sqs";
            awsRegion: string;
            eventSourceARN: string;
            receiptHandle: string;
            attributes: {
                ApproximateReceiveCount: string;
                ApproximateFirstReceiveTimestamp: string;
                SenderId: string;
                SentTimestamp: string;
                MessageDeduplicationId?: string | undefined;
                MessageGroupId?: string | undefined;
                SequenceNumber?: string | undefined;
                AWSTraceHeader?: string | undefined;
                DeadLetterQueueSourceArn?: string | undefined;
            };
            messageAttributes: Record<string, {
                dataType: string;
                stringValue?: string | undefined;
                binaryValue?: string | undefined;
                stringListValues?: string[] | undefined;
                binaryListValues?: string[] | undefined;
            }>;
            md5OfBody: string;
            md5OfMessageAttributes?: string | null | undefined;
        } | undefined);
        approximateArrivalTimestamp: number;
        recordId: string;
        kinesisRecordMetaData?: {
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
            shardId: string;
            subsequenceNumber: number;
        } | undefined;
    }, {
        data: string;
        approximateArrivalTimestamp: number;
        recordId: string;
        kinesisRecordMetaData?: {
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
            shardId: string;
            subsequenceNumber: number;
        } | undefined;
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    region: string;
    records: {
        data: (string | {
            messageId: string;
            body: string;
            eventSource: "aws:sqs";
            awsRegion: string;
            eventSourceARN: string;
            receiptHandle: string;
            attributes: {
                ApproximateReceiveCount: string;
                ApproximateFirstReceiveTimestamp: string;
                SenderId: string;
                SentTimestamp: string;
                MessageDeduplicationId?: string | undefined;
                MessageGroupId?: string | undefined;
                SequenceNumber?: string | undefined;
                AWSTraceHeader?: string | undefined;
                DeadLetterQueueSourceArn?: string | undefined;
            };
            messageAttributes: Record<string, {
                dataType: string;
                stringValue?: string | undefined;
                binaryValue?: string | undefined;
                stringListValues?: string[] | undefined;
                binaryListValues?: string[] | undefined;
            }>;
            md5OfBody: string;
            md5OfMessageAttributes?: string | null | undefined;
        }) & (string | {
            messageId: string;
            body: string;
            eventSource: "aws:sqs";
            awsRegion: string;
            eventSourceARN: string;
            receiptHandle: string;
            attributes: {
                ApproximateReceiveCount: string;
                ApproximateFirstReceiveTimestamp: string;
                SenderId: string;
                SentTimestamp: string;
                MessageDeduplicationId?: string | undefined;
                MessageGroupId?: string | undefined;
                SequenceNumber?: string | undefined;
                AWSTraceHeader?: string | undefined;
                DeadLetterQueueSourceArn?: string | undefined;
            };
            messageAttributes: Record<string, {
                dataType: string;
                stringValue?: string | undefined;
                binaryValue?: string | undefined;
                stringListValues?: string[] | undefined;
                binaryListValues?: string[] | undefined;
            }>;
            md5OfBody: string;
            md5OfMessageAttributes?: string | null | undefined;
        } | undefined);
        approximateArrivalTimestamp: number;
        recordId: string;
        kinesisRecordMetaData?: {
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
            shardId: string;
            subsequenceNumber: number;
        } | undefined;
    }[];
    invocationId: string;
    deliveryStreamArn: string;
    sourceKinesisStreamArn?: string | undefined;
}, {
    region: string;
    records: {
        data: string;
        approximateArrivalTimestamp: number;
        recordId: string;
        kinesisRecordMetaData?: {
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
            shardId: string;
            subsequenceNumber: number;
        } | undefined;
    }[];
    invocationId: string;
    deliveryStreamArn: string;
    sourceKinesisStreamArn?: string | undefined;
}>;
export { KinesisFirehoseSchema, KinesisFirehoseSqsSchema };
//# sourceMappingURL=kinesis-firehose.d.ts.map